diff --git a/plugin.xml b/plugin.xml
index d555ac384..709151af4 100755
--- a/plugin.xml
+++ b/plugin.xml
@@ -116,13 +116,13 @@
production
-
+
-
+
diff --git a/src/ios/CDVAppDelegate+notification.h b/src/ios/AppDelegate+PushPlugin.h
similarity index 78%
rename from src/ios/CDVAppDelegate+notification.h
rename to src/ios/AppDelegate+PushPlugin.h
index b0cc00b0f..2d78b38a3 100644
--- a/src/ios/CDVAppDelegate+notification.h
+++ b/src/ios/AppDelegate+PushPlugin.h
@@ -1,14 +1,14 @@
//
-// CDVAppDelegate+notification.h
+// AppDelegate+PushPlugin.h
//
// Created by Robert Easterday on 10/26/12.
//
-#import
+#import "AppDelegate.h"
@import UserNotifications;
-@interface CDVAppDelegate (notification)
+@interface AppDelegate (PushPlugin)
- (void)application:(UIApplication *)application didRegisterForRemoteNotificationsWithDeviceToken:(NSData *)deviceToken;
- (void)application:(UIApplication *)application didFailToRegisterForRemoteNotificationsWithError:(NSError *)error;
diff --git a/src/ios/PushPlugin.m b/src/ios/PushPlugin.m
index 394a6e740..d4404c56e 100644
--- a/src/ios/PushPlugin.m
+++ b/src/ios/PushPlugin.m
@@ -24,7 +24,6 @@
*/
#import "PushPlugin.h"
-#import "CDVAppDelegate+notification.h"
#import "PushPluginConstants.h"
#import "PushPluginFCM.h"
#import "PushPluginSettings.h"
@@ -350,7 +349,7 @@ - (void)willPresentNotification:(NSNotification *)notification {
UIApplicationState applicationState = [UIApplication sharedApplication].applicationState;
NSNumber *applicationStateNumber = @((int)applicationState);
- // The original notification that comes from the CDVAppDelegate's willPresentNotification.
+ // The original notification that comes from the AppDelegate's willPresentNotification.
UNNotification *originalNotification = notification.userInfo[@"notification"];
NSDictionary *originalUserInfo = originalNotification.request.content.userInfo;
NSMutableDictionary *modifiedUserInfo = [originalUserInfo mutableCopy];
@@ -399,7 +398,7 @@ - (void)willPresentNotification:(NSNotification *)notification {
}
- (void)didReceiveNotificationResponse:(NSNotification *)notification {
- // The original response that comes from the CDVAppDelegate's didReceiveNotificationResponse.
+ // The original response that comes from the AppDelegate's didReceiveNotificationResponse.
UNNotificationResponse *response = notification.userInfo[@"response"];
NSLog(@"[PushPlugin] Notification was received. (actionIdentifier %@, notification: %@)",
diff --git a/src/ios/CDVAppDelegate+notification.m b/src/ios/AppDelegate+PushPlugin.m
similarity index 92%
rename from src/ios/CDVAppDelegate+notification.m
rename to src/ios/AppDelegate+PushPlugin.m
index a907b77cd..66e369f9b 100644
--- a/src/ios/CDVAppDelegate+notification.m
+++ b/src/ios/AppDelegate+PushPlugin.m
@@ -1,15 +1,15 @@
//
-// CDVAppDelegate+notification.m
+// AppDelegate+PushPlugin.m
//
// Created by Robert Easterday on 10/26/12.
//
-#import "CDVAppDelegate+notification.h"
+#import "AppDelegate+PushPlugin.h"
#import "PushPlugin.h"
#import "PushPluginConstants.h"
#import
-@implementation CDVAppDelegate (notification)
+@implementation AppDelegate (PushPlugin)
// its dangerous to override a method from within a category.
// Instead we will use method swizzling. we set this up in the load call.
@@ -34,10 +34,10 @@ + (void)load {
});
}
-- (CDVAppDelegate *)pushPluginSwizzledInit {
+- (AppDelegate *)pushPluginSwizzledInit {
UNUserNotificationCenter *center = [UNUserNotificationCenter currentNotificationCenter];
center.delegate = self;
// This actually calls the original init method over in CDVAppDelegate. Equivilent to calling super
// on an overrided method, this is not recursive, although it appears that way. neat huh?
return [self pushPluginSwizzledInit];
}
@@ -34,10 +34,10 @@ + (void)load {
UNUserNotificationCenter *center = [UNUserNotificationCenter currentNotificationCenter];
center.delegate = self;
- // This actually calls the original init method over in CDVAppDelegate. Equivilent to calling super
+ // This actually calls the original init method over in AppDelegate. Equivilent to calling super
// on an overrided method, this is not recursive, although it appears that way. neat huh?
return [self pushPluginSwizzledInit];